@@ -117,7 +117,7 @@ except NameError:
     DEAD_ENGINE_ERRORS = (EOFError, IOError)
 
 
-__version__ = "1.16.19"
+__version__ = "1.16.22"
 
 __author__ = "Bajusz Tamás"
 __email__ = "gbtami@gmail.com"
@@ -184,6 +184,7 @@ required_variants = set([
     "ordamirror",
     "chak",
     "chennis",
+    "duck",
 ])
 
 
@@ -594,8 +595,6 @@ def go(p, position, moves, movetime=None, clock=None, depth=None, nodes=None, va
 def set_variant_options(p, variant, chess960, nnue):
     variant = variant.lower()
 
-    setoption(p, "Protocol", "uci")
-
     setoption(p, "UCI_Chess960", chess960)
 
     if (variant in NNUE_NET or variant in NNUE_ALIAS) and nnue:
